@@ -63,16 +63,16 @@ igraph_bool_t igraph_i_motifs_randesu_update_hist(const igraph_t *graph,
  * \brief Count the number of motifs in a graph
  * 
  * </para><para>
- * Motifs are small subgraphs of a given structure in a graph. It is
- * argued that the motif profile (ie. the number of different motifs
- * in the graph) is characteristic for different types of networks and
- * network function is related to the motifs in the graph. 
+ * Motifs are small connected subgraphs of a given structure in a
+ * graph. It is argued that the motif profile (ie. the number of
+ * different motifs in the graph) is characteristic for different
+ * types of networks and network function is related to the motifs in
+ * the graph.
  * 
  * </para><para>
  * This function is able to find the different motifs of size three
  * and four (ie. the number of different subgraphs with three and four
- * vertices) in the network. (This limitation is the result of the
- * lack of code to decide graph isomorphism for larger graphs.)
+ * vertices) in the network.
  * 
  * </para><para>
  * In a big network the total number of motifs can be very large, so
@@ -95,6 +95,9 @@ igraph_bool_t igraph_i_motifs_randesu_update_hist(const igraph_t *graph,
  * \param hist The result of the computation, it gives the number of
  *        motifs found for each isomorphism class. See
  *        \ref igraph_isoclass() for help about isomorphism classes.
+ *        Note that this function does \em not count isomorphism
+ *        classes that are not connected and will report NaN (more
+ *        precisely \c IGRAPH_NAN) for them.
  * \param size The size of the motifs to search for. Only three and
  *        four are implemented currently. The limitation is not in the
  *        motif finding code, but the graph isomorphism code.
@@ -134,6 +137,26 @@ int igraph_motifs_randesu(const igraph_t *graph, igraph_vector_t *hist,
   IGRAPH_CHECK(igraph_motifs_randesu_callback(graph, size, cut_prob,
 	&igraph_i_motifs_randesu_update_hist, hist));
 
+  if (size == 3) {
+    if (igraph_is_directed(graph)) {
+      VECTOR(*hist)[0] = VECTOR(*hist)[1] = VECTOR(*hist)[3] = IGRAPH_NAN;
+    } else {
+      VECTOR(*hist)[0] = VECTOR(*hist)[1] = IGRAPH_NAN;
+    }
+  } else if (size == 4) {
+    if (igraph_is_directed(graph)) {
+      int not_connected[] = { 0, 1, 2, 4, 5, 6, 9, 10, 11, 15, 22, 23, 27,
+			      28, 33, 34, 39, 62, 120 };
+      int i, n=sizeof(not_connected) / sizeof(int);
+      for (i=0; i<n; i++) {
+	VECTOR(*hist)[not_connected[i]] = IGRAPH_NAN;
+      }
+    } else {
+      VECTOR(*hist)[0] = VECTOR(*hist)[1] = VECTOR(*hist)[2] = 
+      VECTOR(*hist)[3] = VECTOR(*hist)[5] = IGRAPH_NAN;
+    }
+  }
+
   return IGRAPH_SUCCESS;
 }
 
@@ -816,20 +839,60 @@ int igraph_motifs_randesu_no(const igraph_t *graph, igraph_integer_t *no,
 int igraph_dyad_census(const igraph_t *graph, igraph_integer_t *mut,
 		       igraph_integer_t *asym, igraph_integer_t *null) {
   
+  igraph_integer_t nonrec=0, rec=0;
+  igraph_vector_t inneis, outneis;
   igraph_integer_t vc=igraph_vcount(graph);
-  igraph_integer_t ec=igraph_ecount(graph);
-  igraph_real_t rec;
+	long int i;
 
   if (!igraph_is_directed(graph)) {
     IGRAPH_WARNING("Dyad census called on undirected graph");
   }
 
-  IGRAPH_CHECK(igraph_reciprocity(graph, &rec, /*loops=*/1, 
-				  IGRAPH_RECIPROCITY_RATIO));
-  *mut = rec*ec/(rec+1);
-  *asym = ec-2*(*mut);
-  *null = vc*(vc-1)/2-(*mut)-(*asym);
-  
+  IGRAPH_VECTOR_INIT_FINALLY(&inneis, 0);
+  IGRAPH_VECTOR_INIT_FINALLY(&outneis, 0);
+
+  for (i=0; i<vc; i++) {
+    long int ip, op;
+    igraph_neighbors(graph, &inneis, i, IGRAPH_IN);
+    igraph_neighbors(graph, &outneis, i, IGRAPH_OUT);
+
+    ip=op=0;
+    while (ip < igraph_vector_size(&inneis) &&
+					 op < igraph_vector_size(&outneis)) {
+      if (VECTOR(inneis)[ip] < VECTOR(outneis)[op]) {
+				nonrec += 1;
+				ip++;
+      } else if (VECTOR(inneis)[ip] > VECTOR(outneis)[op]) {
+				nonrec += 1;
+				op++;
+      } else {
+				rec += 1;
+				ip++;
+				op++;
+      }
+    }
+    nonrec += (igraph_vector_size(&inneis)-ip) +
+      (igraph_vector_size(&outneis)-op);
+  }
+
+  igraph_vector_destroy(&inneis);
+  igraph_vector_destroy(&outneis);
+  IGRAPH_FINALLY_CLEAN(2);
+
+	*mut = rec / 2;
+	*asym = nonrec / 2;
+	if (vc % 2) { 
+		*null = vc * ((vc-1)/2);
+	} else {
+		*null = (vc/2) * (vc-1);
+	}
+	if (*null < vc) {
+		IGRAPH_WARNING("Integer overflow, returning zero");
+		*null = IGRAPH_NAN;
+	} else {
+		*null = *null-(*mut)-(*asym);
+	}
+
   return 0;
 }
 
